@@ -1,7 +1,7 @@
 package App::rmhere;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -168,7 +168,7 @@ App::rmhere - Delete files in current directory
 
 =head1 VERSION
 
-This document describes version 0.05 of App::rmhere (from Perl distribution App-rmhere), released on 2015-08-17.
+This document describes version 0.06 of App::rmhere (from Perl distribution App-rmhere), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -181,7 +181,7 @@ See L<rmhere> script.
 
 =head2 rmhere(%args) -> [status, msg, result, meta]
 
-{en_US Delete files in current directory}.
+Delete files in current directory.
 
 This function supports dry-run operation.
 
@@ -192,27 +192,25 @@ Arguments ('*' denotes required arguments):
 
 =item * B<estimate> => I<bool>
 
-{en_US Count files first before start deleting}.
+Count files first before start deleting.
 
-{en_US 
 With this opotion, the program will do an C<opendir> and list the directory
 first. This can take several minutes if the directory is large, so the program
 will not start deleting after several minutes. But with this option, we know how
 many files we want to delete, so the progress report will know when to reach
 100%.
-}
 
 =item * B<here> => I<str>
 
-{en_US Override current directory}.
+Override current directory.
 
 =item * B<interactive> => I<bool> (default: 1)
 
-{en_US Whether to ask first before deleting each file}.
+Whether to ask first before deleting each file.
 
 =item * B<progress> => I<bool>
 
-{en_US Show progress report}.
+Show progress report.
 
 =back
 
